@@ -3,7 +3,7 @@
  */
 
 /*
- * Copyright (C) 2006-2022 Oracle and/or its affiliates.
+ * Copyright (C) 2006-2025 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -115,6 +115,18 @@ RTR0DECL(RTR0PROCESS) RTR0ProcHandleSelf(void);
 #endif
 
 
+/**
+ * Translate a signal number to a short name on the form SIGXXXX.
+ *
+ * If the signal is not known, it will be formatted as a number into one of
+ * several static buffers.  This means that there could be concurrency issues if
+ * this suddenly happens on multiple threads, though that is unlikely.
+ *
+ * @returns Readonly string naming the signal.
+ * @param   iSignal         The signal to name.
+ */
+RTDECL(const char *) RTProcSignalName(int iSignal);
+
 #ifdef IN_RING3
 
 /**
@@ -180,6 +192,10 @@ RTR3DECL(int)   RTProcCreate(const char *pszExec, const char * const *papszArgs,
  * @param   pvExtraData Points to additional data as per @a fFlags:
  *                          - RTPROC_FLAGS_DESIRED_SESSION_ID: Pointing to a
  *                            uint32_t variable with the desired session ID.
+ *                          - RTPROC_FLAGS_CWD: Pointing to a string constant
+ *                            with the directory to chdir() to under the final
+ *                            execution ID, before starting the process.
+ *                          - These flags cannot be used in the same call.
  * @param   phProcess   Where to store the process handle on successful return.
  *                      The content is not changed on failure.  NULL is allowed.
  *
@@ -240,7 +256,7 @@ RTR3DECL(int)   RTProcCreateEx(const char *pszExec, const char * const *papszArg
 /** For use with RTPROC_FLAGS_SERVICE to specify a desired session ID
  * (Windows only, ignored elsewhere).  The @a pvExtraData argument points to
  * a uint32_t containing the session ID, UINT32_MAX means any session.
- * Can not be set with RTPROC_FLAGS_TOKEN_SUPPLIED */
+ * Cannot be set with RTPROC_FLAGS_TOKEN_SUPPLIED or RTPROC_FLAGS_CWD. */
 #define RTPROC_FLAGS_DESIRED_SESSION_ID     RT_BIT(11)
 /** This is a modifier to RTPROC_FLAGS_PROFILE on unix systems that makes it
  * skip trying to dump the environment of a login shell. */
@@ -250,12 +266,17 @@ RTR3DECL(int)   RTProcCreateEx(const char *pszExec, const char * const *papszArg
 #define RTPROC_FLAGS_UTF8_ARGV              RT_BIT_32(13)
 /** Create process using supplied token. The @a pvExtraData argument points to
  * a HANDLE containing the token used as user credentials for process creation.
- * Can not be set with RTPROC_FLAGS_DESIRED_SESSION_ID.
+ * Cannot be set with RTPROC_FLAGS_DESIRED_SESSION_ID or RTPROC_FLAGS_CWD.
  * Windows only flag, ignored everywhere else. */
 #define RTPROC_FLAGS_TOKEN_SUPPLIED         RT_BIT(14)
+/** The @a pvExtraData argument points to a string containing the directory
+ * to chdir() to, under the final execution ID, before starting the process.
+ * Cannot be set with RTPROC_FLAGS_DESIRED_SESSION_ID or
+ * RTPROC_FLAGS_TOKEN_SUPPLIED. */
+#define RTPROC_FLAGS_CWD                    RT_BIT(15)
 
 /** Valid flag mask. */
-#define RTPROC_FLAGS_VALID_MASK             UINT32_C(0x7fff)
+#define RTPROC_FLAGS_VALID_MASK             UINT32_C(0xffff)
 /** @}  */
 
 
@@ -457,6 +478,39 @@ RTR3DECL(int)   RTProcQueryUsername(RTPROCESS hProcess, char *pszUser, size_t cb
  */
 RTR3DECL(int)   RTProcQueryUsernameA(RTPROCESS hProcess, char **ppszUser);
 
+/**
+ * Query the executable path of the given process.
+ *
+ * @returns IPRT status code.
+ * @retval VERR_BUFFER_OVERFLOW if the given buffer size is to small for the executable path.
+ * @param   hProcess     The process handle to query the executable path for.
+ *                       NIL_PROCESS is an alias for the current process.
+ * @param   pszExecPath  Where to store the executable path on success.
+ * @param   cbExecPath   The size of the executable path buffer.
+ * @param   pcbExecPath  Where to store the executable path length on success
+ *                       or the required buffer size if VERR_BUFFER_OVERFLOW
+ *                       is returned.  Optional.
+ *
+ * @note    On Windows, the returned path is currently an NT path.  We assume
+ *          this isn't too much of a problem at present as this is mostly for
+ *          informational use.
+ */
+RTR3DECL(int)   RTProcQueryExecutablePath(RTPROCESS hProcess, char *pszExecPath, size_t cbExecPath, size_t *pcbExecPath);
+
+/**
+ * Query the executable path of the given process.
+ *
+ * @returns IPRT status code.
+ * @param   hProcess     The process handle to query the executable path for.
+ * @param   ppszExecPath Where to store the pointer to the string containing
+ *                       the executable path on success. Free with RTStrFree().
+ *
+ * @note    On Windows, the returned path is currently an NT path.  We assume
+ *          this isn't too much of a problem at present as this is mostly for
+ *          informational use.
+ */
+RTR3DECL(int)   RTProcQueryExecutablePathA(RTPROCESS hProcess, char **ppszExecPath);
+
 #endif /* IN_RING3 */
 
 /** @} */
